==> seabreeze-1.1.0.tar.gz: seabreeze-1.1.0/src/libseabreeze/src/vendors/OceanOptics/features/spectrometer/ProgrammableSaturationFeatureBase.cpp <==
/***************************************************//**
 * @file    ProgrammableSaturationFeatureBase.cpp
 * @date    March 2016
 * @author  Ocean Optics, Inc.
 *
 * LICENSE:
 *
 * SeaBreeze Copyright (C) 2016, Ocean Optics Inc
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject
 * to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *******************************************************/

#include "vendors/OceanOptics/features/spectrometer/ProgrammableSaturationFeatureBase.h"
#include "api/seabreezeapi/FeatureFamilies.h"

using namespace seabreeze;
using namespace api;

#ifdef _WINDOWS
#pragma warning (disable: 4101) // unreferenced local variable
#endif

ProgrammableSaturationFeatureBase::ProgrammableSaturationFeatureBase() {
    this->saturation = 0;
    this->valid = false;
}

ProgrammableSaturationFeatureBase::~ProgrammableSaturationFeatureBase() {

}

bool ProgrammableSaturationFeatureBase::initialize(const Protocol &protocol,
        const Bus &bus) {
    try {
        this->saturation = getSaturation(protocol, bus);
        this->valid = true;
    } catch (FeatureException &fe) {
        this->valid = false;
    }
    
    return true;
}

unsigned int ProgrammableSaturationFeatureBase::getSaturation() {
    if(false == this->valid) {
        throw FeatureException("Saturation level not properly initialized");
    }
    
    return this->saturation;
}

FeatureFamily ProgrammableSaturationFeatureBase::getFeatureFamily() {
    FeatureFamilies families;

    return families.UNDEFINED;
}

==> seabreeze-1.2.0.tar.gz: seabreeze-1.2.0/src/libseabreeze/src/vendors/OceanOptics/features/spectrometer/ProgrammableSaturationFeatureBase.cpp <==
/***************************************************//**
 * @file    ProgrammableSaturationFeatureBase.cpp
 * @date    March 2016
 * @author  Ocean Optics, Inc.
 *
 * LICENSE:
 *
 * SeaBreeze Copyright (C) 2016, Ocean Optics Inc
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject
 * to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *******************************************************/

#include "vendors/OceanOptics/features/spectrometer/ProgrammableSaturationFeatureBase.h"
#include "api/seabreezeapi/FeatureFamilies.h"

using namespace seabreeze;
using namespace api;

#ifdef _WINDOWS
#pragma warning (disable: 4101) // unreferenced local variable
#endif

ProgrammableSaturationFeatureBase::ProgrammableSaturationFeatureBase() {
    this->saturation = 0;
    this->valid = false;
}

ProgrammableSaturationFeatureBase::~ProgrammableSaturationFeatureBase() {

}

bool ProgrammableSaturationFeatureBase::initialize(const Protocol &protocol,
        const Bus &bus) {
    try {
        this->saturation = getSaturation(protocol, bus);
        this->valid = true;
    } catch (const FeatureException &fe) {
        this->valid = false;
    }
    
    return true;
}

unsigned int ProgrammableSaturationFeatureBase::getSaturation() {
    if(false == this->valid) {
        throw FeatureException("Saturation level not properly initialized");
    }
    
    return this->saturation;
}

FeatureFamily ProgrammableSaturationFeatureBase::getFeatureFamily() {
    FeatureFamilies families;

    return families.UNDEFINED;
}
